"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CCashClient = void 0;
const axios_1 = require("axios");
const class_transformer_1 = require("class-transformer");
const CCashClient_types_1 = require("./CCashClient.types");
const CCashClient_exceptions_1 = require("./CCashClient.exceptions");
class CCashClient {
    constructor(baseURL = process.env.CCASH_API_BASE_URL) {
        this.serialize = class_transformer_1.plainToClass;
        if (!baseURL) {
            throw new CCashClient_exceptions_1.BaseUrlMissingException();
        }
        this.http = axios_1.default.create({
            baseURL,
        });
    }
    balance(user) {
        return this.http
            .get(`/${user}/bal`)
            .then((response) => this.handleError(response) || response.data.value);
    }
    log(user, pass) {
        return this.http
            .get(`/${user}/bal`, {
            headers: { Password: pass },
        })
            .then((response) => this.handleError(response) || response.data.value);
    }
    sendFunds(user, pass, to, amount) {
        return this.http
            .post(`/${user}/send/${to}`, {
            headers: { Password: pass },
            params: { amount },
        })
            .then((response) => this.handleError(response) || amount);
    }
    verifyPassword(user, pass) {
        return this.http
            .get(`/${user}/pass/verify`, { headers: { Password: pass } })
            .then((response) => this.handleError(response) || response.data.value);
    }
    changePassword(user, pass, newPass) {
        return this.http
            .patch(`/${user}/pass/change`, newPass, { headers: { Password: pass } })
            .then((response) => this.handleError(response) || this.serialize(CCashClient_types_1.User, { user }));
    }
    setBalance(user, pass, amount) {
        return this.http
            .patch(`/admin/${user}/bal`, undefined, {
            headers: { Password: pass },
            params: { amount },
        })
            .then((response) => this.handleError(response) || amount);
    }
    help() {
        return this.http.get('/help').then((response) => response.data);
    }
    ping() {
        return this.http.get('/ping').then((response) => response.data || false);
    }
    close(pass) {
        return this.http
            .post('/close', undefined, { headers: { Password: pass } })
            .then((response) => this.handleError(response) || true);
    }
    contains(user) {
        return this.http
            .get(`/contains/${user}`)
            .then((response) => this.handleError(response) || response.data.value || false);
    }
    adminVerifyPass(pass) {
        return this.http
            .get('/admin/verify')
            .then((response) => this.handleError(response) || response.data.value || false);
    }
    addUser(user, pass) {
        return this.http
            .post(`/user/${user}`, undefined, { headers: { Password: pass } })
            .then((response) => this.handleError(response) || this.serialize(CCashClient_types_1.User, { user }));
    }
    adminAddUser(user, pass, initialPass, initialBalance) {
        return this.http
            .post(`/user/${user}`, initialPass, {
            headers: { Password: pass },
            params: { init_bal: initialBalance },
        })
            .then((response) => this.handleError(response) || this.serialize(CCashClient_types_1.User, { user }));
    }
    deleteUser(user, pass) {
        return this.http
            .delete(`/user/${user}`, { headers: { Password: pass } })
            .then((response) => this.handleError(response) || this.serialize(CCashClient_types_1.User, { user }));
    }
    adminDeleteUser(user, pass) {
        return this.http
            .delete(`/user/${user}`, { headers: { Password: pass } })
            .then((response) => this.handleError(response) || this.serialize(CCashClient_types_1.User, { user }));
    }
    handleError(response) {
        if (response.data.value &&
            Object.values(CCashClient_exceptions_1.ErrorCodes).includes(response.data.value)) {
            throw new CCashClient_exceptions_1.ExceptionMap[response.data.value]();
        }
        return false;
    }
}
exports.CCashClient = CCashClient;
